@@ -52,12 +52,41 @@ def of_file(fp):
   if not ok:
     # The file doesn't exist.
     return FILE_NOT_FOUND
-  return _status_file(fp)
+  s = _status_porcelain(fp).get(fp, None)
+  return _status_from_output(s, _is_au_file(fp), fp)
+
+
+def of_repo(include_tracked_unmodified_fps=True):
+  """Gets the status of the repo relative to the cwd.
+
+  Args:
+    include_tracked_unmodified_fps: if True, files that are tracked but
+      unmodified will be also reported. Setting it to False improves performance
+      significantly if the repo is big. (Defaults to True.)
+
+  Yields:
+      A pair (status, fp) for each file in the repo. fp is a file path and
+      status is the status of the file (TRACKED_UNMODIFIED, TRACKED_MODIFIED,
+      UNTRACKED, ASSUME_UNCHANGED, STAGED, etc -- see above).
+  """
+  status_codes = _status_porcelain(os.getcwd())
+  au_fps = set(au_files(relative_to_cwd=True))
+  for au_fp in au_fps:
+    if au_fp not in status_codes:
+      status_codes[au_fp] = None
+  if include_tracked_unmodified_fps:
+    all_fps_under_cwd = common.get_all_fps_under_cwd()
+    for fp_under_cwd in all_fps_under_cwd:
+      if fp_under_cwd not in status_codes:
+        status_codes[fp_under_cwd] = None
+  for s_fp, s in status_codes.iteritems():
+    status = _status_from_output(s, s_fp in au_fps, s_fp)
+    yield (status, s_fp)
 
 
 def au_files(relative_to_cwd=False):
   """Gets all assumed unchanged files.
-  
+
   Args:
     relative_to_cwd: if True then only those au files under the cwd are
       reported. If False, all au files in the repository are reported. (Defaults
@@ -76,40 +105,9 @@ def au_files(relative_to_cwd=False):
   return ret
 
 
-def of_repo():
-  """Gets the status of the repo relative to the cwd.
-
-  Yields:
-      A pair (status, fp) for each file in the repo. fp is a file path and
-      status is the status of the file (TRACKED_UNMODIFIED, TRACKED_MODIFIED,
-      UNTRACKED, ASSUME_UNCHANGED, STAGED, etc -- see above).
-  """
-  return _status_cwd()
-
-
 # Private functions.
 
 
-def _status_cwd():
-  status_codes = _status_porcelain(os.getcwd())
-  au_fps = set(au_files(relative_to_cwd=True))
-  for au_fp in au_fps:
-    if au_fp not in status_codes:
-      status_codes[au_fp] = None
-  all_fps_under_cwd = common.get_all_fps_under_cwd()
-  for fp_under_cwd in all_fps_under_cwd:
-    if fp_under_cwd not in status_codes:
-      status_codes[fp_under_cwd] = None
-  for s_fp, s in status_codes.iteritems():
-    status = _status_from_output(s, s_fp in au_fps, s_fp)
-    yield (status, s_fp)
-
-
-def _status_file(fp):
-  s = _status_porcelain(fp).get(fp, None)
-  return _status_from_output(s, _is_au_file(fp), fp)
-
-
 def _is_au_file(fp):
   """True if the given fp corresponds to an assume unchanged file.
 
@@ -135,15 +133,17 @@ def _status_porcelain(pathspec):
   Returns:
     A dict of fp -> status code. All fps are relative to the cwd.
   """
-  def sanitize_fp(unsanitized_fp):
-    ret = unsanitized_fp.strip()
-    if ret.startswith('"') and ret.endswith('"'):
-      ret = ret[1:-1]
+  cwd = os.getcwd()
+  repo_dir = common.repo_dir()
+
+  def sanitize_fp(fp):
+    # The more pythonic way would be to use startswith instead of [0] but the
+    # latter is faster and it makes a difference when the repo is big.
+    if fp[0] == '"' and fp.endswith('"'):
+      fp = fp[1:-1]
     # The paths outputted by status are relative to the repodir, we need to make
     # them relative to the cwd.
-    ret = os.path.relpath(
-        os.path.join(common.repo_dir(), ret), os.getcwd())
-    return ret
+    return os.path.relpath(os.path.join(repo_dir, fp), cwd)
 
   out_status, unused_err = common.safe_git_call(
       'status --porcelain -u --ignored "{}"'.format(pathspec))
